@@ -23,7 +23,7 @@ pub(crate) struct AzureCredentials {
 }
 
 impl AzureCredentials {
-    pub(crate) fn validate(&self) -> anyhow::Result<()> {
+    pub(super) fn validate(&self) -> anyhow::Result<()> {
         let all = self.azure_tenant_id.is_some()
             && self.azure_client_id.is_some()
             && self.azure_client_secret.is_some();
