@@ -26,6 +26,7 @@ pub(super) struct RegisterCluster {
     default_state: Option<String>,
     claim_unowned_states: bool,
     cleanup_grace: String,
+    aws: AwsCredentials,
     azure: AzureCredentials,
 }
 
@@ -39,6 +40,7 @@ impl RegisterCluster {
         default_state: Option<String>,
         claim_unowned_states: bool,
         cleanup_grace: String,
+        aws: AwsCredentials,
         azure: AzureCredentials,
     ) -> Self {
         Self {
@@ -49,6 +51,7 @@ impl RegisterCluster {
             default_state,
             claim_unowned_states,
             cleanup_grace,
+            aws,
             azure,
         }
     }
@@ -73,6 +76,7 @@ impl StateHub {
         skip_helm: bool,
         provider: Option<v0::Provider>,
         cleanup_grace: String,
+        aws: AwsCredentials,
         azure: AzureCredentials,
     ) -> anyhow::Result<(Vec<k8s::Kubectl>, RegisterCluster)> {
         anyhow::ensure!(
@@ -153,7 +157,14 @@ impl StateHub {
             && unowned_states
             && self.confirm_with_default("Claim ownership of unowned states", true);
 
-        azure.validate()?;
+        if let Ok(locations) = kubectl.collect_node_locations().await {
+            if locations.iter().any(|location| location.is_aws()) {
+                self.aws_credentials_helper(&aws).await?;
+            }
+            if locations.iter().any(|location| location.is_azure()) {
+                self.azure_credentials_helper(&azure).await?;
+            }
+        }
 
         let register_cluster = RegisterCluster::new(
             helm,
@@ -163,6 +174,7 @@ impl StateHub {
             default_state,
             claim_unowned_states,
             cleanup_grace,
+            aws,
             azure,
         );
 
@@ -183,6 +195,7 @@ impl StateHub {
         skip_helm: bool,
         provider: Option<v0::Provider>,
         cleanup_grace: String,
+        aws: AwsCredentials,
         azure: AzureCredentials,
     ) -> anyhow::Result<(Vec<k8s::Kubectl>, RegisterCluster)> {
         let kubectls = k8s::Kubectl::with_names_and_contexts(names, contexts)?;
@@ -205,7 +218,8 @@ impl StateHub {
 
         let helm = k8s::Helm::new(skip_helm);
 
-        azure.validate()?;
+        self.aws_credentials_helper(&aws).await?;
+        self.azure_credentials_helper(&azure).await?;
 
         let register_cluster = RegisterCluster::new(
             helm,
@@ -215,6 +229,7 @@ impl StateHub {
             default_state,
             claim_unowned_states,
             cleanup_grace,
+            aws,
             azure,
         );
 
@@ -262,8 +277,8 @@ impl StateHub {
         self.setup_credentials_helper(
             &kubectl,
             &register_cluster.namespace,
+            Some(&register_cluster.aws),
             Some(&register_cluster.azure),
-            None,
         )
         .await?;
         self.setup_configmap_helper(&kubectl, &cluster, register_cluster)
@@ -321,6 +336,14 @@ impl StateHub {
         Ok(())
     }
 
+    async fn aws_credentials_helper(&self, aws: &AwsCredentials) -> anyhow::Result<()> {
+        aws.validate()
+    }
+
+    async fn azure_credentials_helper(&self, azure: &AzureCredentials) -> anyhow::Result<()> {
+        azure.validate()
+    }
+
     pub(super) async fn add_location_helper(
         &self,
         state: &v0::State,
@@ -544,8 +567,8 @@ or run following commands before running 'statehub register-cluster`
         &self,
         kubectl: &k8s::Kubectl,
         namespace: &str,
+        aws: Option<&AwsCredentials>,
         azure: Option<&AzureCredentials>,
-        aws: Option<()>,
     ) -> anyhow::Result<()> {
         let azure = if let Some(azure) = azure {
             json::to_value(azure)?
